@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup 2.34 {
+package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup 2.35 {
 
   use 5.014;
   use Path::Tiny qw( path );
@@ -18,6 +18,15 @@ package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup 2.34 {
     default => 'plicease',
   );
 
+  has cirrus_user => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub {
+      my($self) = @_;
+      $self->travis_user;
+    },
+  );
+
   has appveyor_user => (
     is      => 'ro',
     default => 'plicease',
@@ -27,7 +36,7 @@ package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup 2.34 {
     is  => 'ro',
     isa => 'Str',
   );
-  
+
   sub after_build
   {
     my($self) = @_;
@@ -36,8 +45,11 @@ package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup 2.34 {
     {
       my $name = $self->zilla->name;
       my $user = $self->travis_user;
-      
+
+      my $cirrus_status = -f $self->zilla->root->child('.cirrus.yml');
+
       my $status = '';
+      $status .= " [![Build Status](https://api.cirrus-ci.com/github/@{[ $self->cirrus_user ]}/$name.svg)](https://cirrus-ci.com/github/@{[ $self->cirrus_user ]}/$name)" if $cirrus_status;
       $status .= " [![Build Status](https://secure.travis-ci.org/$user/$name.png)](http://travis-ci.org/$user/$name)" if $self->travis_status;
       $status .= " [![Build status](https://ci.appveyor.com/api/projects/status/@{[ $self->appveyor ]}/branch/master?svg=true)](https://ci.appveyor.com/project/@{[ $self->appveyor_user ]}/$name/branch/master)" if $self->appveyor;
       
@@ -69,7 +81,7 @@ Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup - add a travis status but
 
 =head1 VERSION
 
-version 2.34
+version 2.35
 
 =head1 SYNOPSIS
 
